@@ -567,3 +567,152 @@ def test_parser_parse_interface_with_inheritance(
     assert parser.prepared == expected_prepared
     assert parser.interface_inheritances == expected_interface_inheritances
     assert parser.flush(True) == expected_result
+
+
+TEST_DATE_DATETIME = """
+    from dataclasses import dataclass
+    from python_to_typescript_interfaces import Interface
+    from datetime import datetime
+
+    @dataclass
+    class Foo(Interface):
+        aaa: datetime
+"""
+TEST_DATE_DATE = """
+    from dataclasses import dataclass
+    from python_to_typescript_interfaces import Interface
+    from datetime import date
+
+    @dataclass
+    class Foo(Interface):
+        aaa: date
+"""
+TEST_DATE_DATETIME_DATETIME = """
+    import datetime
+    from dataclasses import dataclass
+    from python_to_typescript_interfaces import Interface
+
+    @dataclass
+    class Foo(Interface):
+        aaa: datetime.datetime
+"""
+TEST_DATE_DATETIME_DATE = """
+    import datetime
+    from dataclasses import dataclass
+    from python_to_typescript_interfaces import Interface
+
+    @dataclass
+    class Foo(Interface):
+        aaa: datetime.date
+"""
+
+
+@pytest.mark.filterwarnings("ignore::UserWarning")
+@pytest.mark.parametrize(
+    "code, date_transformed_type,  expected_prepared, expected_result",
+    [
+        (
+            TEST_DATE_DATETIME,
+            "string",
+            {"Foo": {"aaa": "string"}},
+            """export interface Foo {\n    aaa: string;\n}\n""",
+        ),
+        (
+            TEST_DATE_DATE,
+            "string",
+            {"Foo": {"aaa": "string"}},
+            """export interface Foo {\n    aaa: string;\n}\n""",
+        ),
+        (
+            TEST_DATE_DATETIME,
+            "number",
+            {"Foo": {"aaa": "number"}},
+            """export interface Foo {\n    aaa: number;\n}\n""",
+        ),
+        (
+            TEST_DATE_DATE,
+            "number",
+            {"Foo": {"aaa": "number"}},
+            """export interface Foo {\n    aaa: number;\n}\n""",
+        ),
+        (
+            TEST_DATE_DATETIME,
+            "Date",
+            {"Foo": {"aaa": "Date"}},
+            """export interface Foo {\n    aaa: Date;\n}\n""",
+        ),
+        (
+            TEST_DATE_DATE,
+            "Date",
+            {"Foo": {"aaa": "Date"}},
+            """export interface Foo {\n    aaa: Date;\n}\n""",
+        ),
+        (
+            TEST_DATE_DATETIME_DATETIME,
+            "string",
+            {"Foo": {"aaa": "string"}},
+            """export interface Foo {\n    aaa: string;\n}\n""",
+        ),
+        (
+            TEST_DATE_DATETIME_DATE,
+            "string",
+            {"Foo": {"aaa": "string"}},
+            """export interface Foo {\n    aaa: string;\n}\n""",
+        ),
+        (
+            TEST_DATE_DATETIME_DATETIME,
+            "number",
+            {"Foo": {"aaa": "number"}},
+            """export interface Foo {\n    aaa: number;\n}\n""",
+        ),
+        (
+            TEST_DATE_DATETIME_DATE,
+            "number",
+            {"Foo": {"aaa": "number"}},
+            """export interface Foo {\n    aaa: number;\n}\n""",
+        ),
+        (
+            TEST_DATE_DATETIME_DATETIME,
+            "Date",
+            {"Foo": {"aaa": "Date"}},
+            """export interface Foo {\n    aaa: Date;\n}\n""",
+        ),
+        (
+            TEST_DATE_DATETIME_DATE,
+            "Date",
+            {"Foo": {"aaa": "Date"}},
+            """export interface Foo {\n    aaa: Date;\n}\n""",
+        ),
+    ],
+)
+def test_parser_parse_date_types(
+    code: str,
+    interface_qualname: str,
+    date_transformed_type: str,
+    expected_prepared: Any,
+    expected_result: str,
+) -> None:
+    parser = Parser(interface_qualname, date_transformed_type)
+    parser.parse(code=code)
+    assert parser.prepared == expected_prepared
+    assert parser.flush(True) == expected_result
+
+
+@pytest.mark.filterwarnings("ignore::UserWarning")
+@pytest.mark.parametrize(
+    "code, expected",
+    [
+        ("foo: List[datetime]", ("foo", "Array<string>")),
+        ("bar: Tuple[date, int]", ("bar", "[string, number]")),
+        ("foo: List[datetime.datetime]", ("foo", "Array<string>")),
+        ("bar: Tuple[datetime.date, int]", ("bar", "[string, number]")),
+    ],
+)
+def test_parse_annassign_node_with_datetime_types(
+    code: str,
+    expected: Any,
+) -> None:
+    parser = Parser(interface_qualname)
+    ann_assign = extract_node(code)
+    assert isinstance(ann_assign, AnnAssign)
+    assert parser.parse_annassign_node(ann_assign, "parent_name") == expected
